==> ccerial-1.0.0-sources.jar: org/gittorr/ccerial/utils/impl/ArrayFieldAccessorWriter.java <==
package org.gittorr.ccerial.utils.impl;

import org.gittorr.ccerial.AccessorType;
import org.gittorr.ccerial.CcArray;
import org.gittorr.ccerial.CcSerializable;
import org.stringtemplate.v4.ST;

import javax.lang.model.element.Element;
import javax.lang.model.type.TypeKind;
import java.io.IOException;
import java.io.Writer;

public class ArrayFieldAccessorWriter extends AbstractFieldAccessorWriter {

    final String writerMethodName;
    final String readerMethodName;

    public ArrayFieldAccessorWriter(TypeKind kind, boolean variable, String typeName, String writerMethodName, String readerMethodName) {
        super(kind, variable, typeName);
        this.writerMethodName = writerMethodName;
        this.readerMethodName = readerMethodName;
    }

    @Override
    public void writeWriter(Writer out, String accessorName, Element fieldEl, CcSerializable ccSerializable, boolean isRecord) throws IOException {
        String variableCount = ", obj." + accessorName + ".length";
        CcArray annotation = fieldEl.getAnnotation(CcArray.class);
        boolean nullIsEmpty = ccSerializable.nullIsZeroOrEmpty();
        String charset = "UTF-8";
        if (annotation != null) {
            variableCount = ", " + annotation.count();
            charset = annotation.stringCharsetName();
        }
        String typeName = fieldEl.asType().toString();
        boolean stringAsWchar = annotation != null && annotation.stringAsCharArray() && typeName.equals("java.lang.String");
        boolean isSstring = (annotation == null || !annotation.stringAsCharArray()) && typeName.equals("java.lang.String");
        if (nullIsEmpty && variable)
            out.write("\t\tif (BinaryUtils.isNullOrEmpty(obj." + accessorName + "))\n" +
                    "\t\t\tout.write(0);\n\t\telse\n\t");
        out.write("\t\tBinaryUtils." + (stringAsWchar ? "writeChars" : writerMethodName) +
                "(out, obj." + accessorName + (stringAsWchar ? ".toCharArray()" : "") + (variable ? "" : variableCount) +
                (!isSstring ? "" : (", \"" + charset + "\"")) +");\n");
    }

    @Override
    public void writeReader(Writer out, String accessorName, Element fieldEl, CcSerializable ccSerializable, boolean isRecord) throws IOException {
        String variableCount = "";
        String charset = "UTF-8";
        CcArray annotation = fieldEl.getAnnotation(CcArray.class);
        String ctorArgName = toCtorArgName(accessorName, isRecord);
        String setterName = toSetterName(accessorName, isRecord);
        if (annotation != null) {
            variableCount = ", " + annotation.count();
            charset = annotation.stringCharsetName();
        }
        String typeName = fieldEl.asType().toString();
        boolean stringAsWchar = annotation != null && annotation.stringAsCharArray() && typeName.equals("java.lang.String");
        boolean isString = (annotation == null || !annotation.stringAsCharArray()) && typeName.equals("java.lang.String");
        String template = "\t\t<if(ctor)><typeName> <ctorArgName> = <else>obj.<setterName>(<endif>" +
                "<if(stringAsWchar)>new String(<endif>BinaryUtils.<readerMethodName>(in<variableCount><if(isString)>, \"<charset>\"<endif>)<if(stringAsWchar)>)<endif>"+
                "<if(!ctor)>)<endif>;\n";
        ST st = new ST(template);
        st.add("variable", variable);
        st.add("stringAsWchar", stringAsWchar);
        st.add("isString", isString);
        st.add("charset", charset);
        st.add("accessorName", accessorName);
        st.add("variableCount", variableCount);
        st.add("typeName", typeName);
        st.add("ctorArgName", ctorArgName);
        st.add("setterName", setterName);
        st.add("ctor", ccSerializable.accessorType() == AccessorType.CONSTRUCTOR);
        st.add("readerMethodName", stringAsWchar ? "readChars" : readerMethodName);
        out.write(st.render());
    }

}

==> ccerial-1.0.1-sources.jar: org/gittorr/ccerial/utils/impl/ArrayFieldAccessorWriter.java <==
/*
 * Copyright 2025 GitTorr
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For inquiries, visit https://gittorr.org
 */
package org.gittorr.ccerial.utils.impl;

import org.gittorr.ccerial.AccessorType;
import org.gittorr.ccerial.CcArray;
import org.gittorr.ccerial.CcSerializable;
import org.gittorr.ccerial.utils.FieldAccessorWriterManager;
import org.stringtemplate.v4.ST;

import javax.lang.model.element.Element;
import javax.lang.model.type.TypeKind;
import java.io.IOException;
import java.io.Writer;

public class ArrayFieldAccessorWriter extends AbstractFieldAccessorWriter {

    final String writerMethodName;
    final String readerMethodName;

    public ArrayFieldAccessorWriter(TypeKind kind, boolean variable, String typeName, String writerMethodName, String readerMethodName) {
        super(kind, variable, typeName);
        this.writerMethodName = writerMethodName;
        this.readerMethodName = readerMethodName;
    }

    @Override
    public void writeWriter(Writer out, String accessorName, Element fieldEl, CcSerializable ccSerializable, boolean isRecord) throws IOException {
        String variableCount = ", obj." + accessorName + ".length";
        CcArray annotation = fieldEl.getAnnotation(CcArray.class);
        boolean nullIsEmpty = ccSerializable.nullIsZeroOrEmpty();
        String charset = "UTF-8";
        if (annotation != null) {
            variableCount = ", " + annotation.count();
            charset = annotation.stringCharsetName();
        }
        String typeName = FieldAccessorWriterManager.getTypeName(fieldEl.asType());
        boolean stringAsWchar = annotation != null && annotation.stringAsCharArray() && typeName.equals("java.lang.String");
        boolean isSstring = (annotation == null || !annotation.stringAsCharArray()) && typeName.equals("java.lang.String");
        if (nullIsEmpty && variable)
            out.write("\t\tif (BinaryUtils.isNullOrEmpty(obj." + accessorName + "))\n" +
                    "\t\t\tout.write(0);\n\t\telse\n\t");
        out.write("\t\tBinaryUtils." + (stringAsWchar ? "writeChars" : writerMethodName) +
                "(out, obj." + accessorName + (stringAsWchar ? ".toCharArray()" : "") + (variable ? "" : variableCount) +
                (!isSstring ? "" : (", \"" + charset + "\"")) +");\n");
    }

    @Override
    public void writeReader(Writer out, String accessorName, Element fieldEl, CcSerializable ccSerializable, boolean isRecord) throws IOException {
        String variableCount = "";
        String charset = "UTF-8";
        CcArray annotation = fieldEl.getAnnotation(CcArray.class);
        String ctorArgName = toCtorArgName(accessorName, isRecord);
        String setterName = toSetterName(accessorName, isRecord);
        if (annotation != null) {
            variableCount = ", " + annotation.count();
            charset = annotation.stringCharsetName();
        }
        String typeName = FieldAccessorWriterManager.getTypeName(fieldEl.asType());
        boolean stringAsWchar = annotation != null && annotation.stringAsCharArray() && typeName.equals("java.lang.String");
        boolean isString = (annotation == null || !annotation.stringAsCharArray()) && typeName.equals("java.lang.String");
        String template = "\t\t<if(ctor)><typeName> <ctorArgName> = <else>obj.<setterName>(<endif>" +
                "<if(stringAsWchar)>new String(<endif>BinaryUtils.<readerMethodName>(in<variableCount><if(isString)>, \"<charset>\"<endif>)<if(stringAsWchar)>)<endif>"+
                "<if(!ctor)>)<endif>;\n";
        ST st = new ST(template);
        st.add("variable", variable);
        st.add("stringAsWchar", stringAsWchar);
        st.add("isString", isString);
        st.add("charset", charset);
        st.add("accessorName", accessorName);
        st.add("variableCount", variableCount);
        st.add("typeName", typeName);
        st.add("ctorArgName", ctorArgName);
        st.add("setterName", setterName);
        st.add("ctor", ccSerializable.accessorType() == AccessorType.CONSTRUCTOR);
        st.add("readerMethodName", stringAsWchar ? "readChars" : readerMethodName);
        out.write(st.render());
    }

}
